            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Course Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="listTable" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th style="width:150px">Code</th>
                                        <th>Course Name</th>
                                        <th>Course Type</th>
                                        <th>Department</th>
                                        <th style="width:50px">Status</th>
                                        <th style="width:100px"></th>
                                    </tr>
                                </thead>                                     
                                <tbody id="tbl_content">
                                    <tr>
                                        <td colspan='4'>
                                            <?php echo loadingText("Loading Course Names");?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
</div>


<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Course Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                <div class="row">
                     <span id="ErrCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Course Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="CourseName" name="CourseName" placeholder="Course Name" value="" onkeypress="clearInput('CourseName')">
                        <span id="ErrCourseName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="CourseTypeID" id="CourseTypeID" onchange="clearInput('CourseTypeID')">
                            <option value="0">Select Course Type</option>
                         </select>
                        <span id="ErrCourseTypeID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Department</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="DepartmentID" id="DepartmentID" onchange="clearInput('DepartmentID')">
                            <option value="0">Select Department</option>
                         </select>
                        <span id="ErrDepartmentID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
                </form>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Course Name</h5>
               <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                 <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
                 <input type="hidden" name="ID" id="editID">
                <div class="row">
                     <span id="ErreditCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label>
                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value=""  onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Course Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editCourseName" name="CourseName" placeholder="Course Name" value="" onkeypress="clearInput('editCourseName')">
                        <span id="ErreditCourseName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Course Type</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="CourseTypeID" id="editCourseTypeID" value="" onchange="clearInput('editCourseTypeID')">
                            <option value="0">Select Course Type</option>
                         </select>
                        <span id="ErreditCourseTypeID" class="error_msg" style="color: red;"></span>
                    </div> 
                    <div class="col-12">
                        <label class="form-label">Department</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="DepartmentID" id="editDepartmentID" value="" onchange="clearInput('editDepartmentID')">
                            <option value="0">Select Department</option>
                         </select>
                        <span id="ErreditDepartmentID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>                           
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1">Active</option>
                            <option value="0">Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
                </form>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Course Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Code</div>
                         <div id="viewCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Course Name</div>
                         <div id="viewCourseName"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Course Type</div>
                         <div id="viewCourseTypeID"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Department</div>
                         <div id="viewDepartmentID"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                         <div id="viewRemarks"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                         <div id="viewStatus"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                         <div id="viewCreatedOn"></div>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
            </div>            
        </div>
    </div>
</div>
     
<script>


function list() {
      $('#Success').modal("hide");
    $.post(URL+ "webservice.php?action=l&method=macoul","",function(data){
      var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            i=0;
            $.each(obj.data, function (index, data) {
                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                            + '<td>' + data.Code + '</td>'
                            + '<td>' + data.CourseName + '</td>' 
                            + '<td>' + data.CourseType + '</td>' 
                            + '<td>' + data.Department + '</td>' 
                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
                             + '<td style="text-align:right">' 
                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macoul\',\''+data.CourseName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                               + '</td>'
                             + '</tr>' 
                      + '</tr>';
                      i++;
            });
            if(obj.data.length==0){
            html += '<tr>'
                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
                + '</tr>'
            }   
            $('#tbl_content').html(html);
        } else {
             $('#popupcontent').html( error(obj.message));
        }  
    });
}

setTimeout("list()",2000);

function addform(){
    listCourseTypes("0","CourseTypeID");
    listDepartments("0","DepartmentID");
        $('#confirmationtoadd').modal("show"); 
        $('#Code').val(""); 
        $('#CourseName').val("");
        $('#Remarks').val("");
        $('#CourseTypeID').val("0");
        $('#DepartmentID').val("0");
        
        $('#ErrCode').html("");
        $('#ErrCourseName').html(""); 
        $('#ErrDepartmentID').html(""); 
        $('#ErrCourseTypeID').html(""); 
        $('#ErrRemarks').html(""); 
        
        $("#Code").removeClass("highlight_error");  
        $("#CourseName").removeClass("highlight_error");  
        $("#DepartmentID").removeClass("highlight_error");  
        $("#CourseTypeID").removeClass("highlight_error");  
        $("#Remarks").removeClass("highlight_error");    
       
}

function add(){
     var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Course Code");
           $("#Code").addClass("highlight_error");
            error++;
    }  else {
         $("#Code").removeClass("highlight_error");
            $('#ErrCode').html(""); 
    }
    
    if ($('#CourseTypeID').val()=="0"){
            $('#ErrCourseTypeID').html("Please select Course Type");
           $("#CourseTypeID").addClass("highlight_error");
           error++;
    }  else {
            $("#CourseTypeID").removeClass("highlight_error");
            $('#ErrCourseTypeID').html(""); 
    } 
    
    if ($('#CourseName').val()==""){
            $('#ErrCourseName').html("Please enter Course Name");
          $("#CourseName").addClass("highlight_error");
            error++;
    }  else {
             $("#CourseName").removeClass("highlight_error");
            $('#ErrCourseName').html(""); 
    }
    if ($('#DepartmentID').val()==""){
            $('#ErrDepartmentID').html("Please enter Department");
          $("#DepartmentID").addClass("highlight_error");
            error++;
    }  else {
             $("#DepartmentID").removeClass("highlight_error");
            $('#ErrDepartmentID').html(""); 
    } 
      if(error==0){
        var param = $('#frm_create').serialize();
        $.post(URL+"webservice.php?action=a&method=macoul",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoadd').modal("hide"); 
             $('#Success').modal("show");    
        }   else {
            $('#ErrCommon').html(print_inlineError(obj.message));
        }
    });
    } 
}

function editform(ID){
     $('#confirmationtoedit').modal("show"); 
     $('#ErreditCode').html("");
     $('#ErreditCourseName').html(""); 
     $('#ErreditDepartmentID').html(""); 
     $('#ErreditCourseTypeID').html(""); 
     $('#ErreditRemarks').html(""); 
     $("#editCode").removeClass("highlight_error");  
     $("#editCourseName").removeClass("highlight_error");  
     $("#editCourseTypeID").removeClass("highlight_error");  
     $("#editRemarks").removeClass("highlight_error");
      $.post(URL+ "webservice.php?action=g&method=macoul&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
             _CourseTypeID="";
            $.each(obj.data, function (index, data) {
                $('#editCode').val(data.Code);
                $('#editID').val(data.ID);
                $('#editDepartment').val(data.Department);
                $('#editCourseName').val(data.CourseName);
                $('#editStatus').val(data.Status);
                $('#editRemarks').val(data.Remarks);
                _CourseTypeID=data.CourseTypeID;
                _DepartmentID=data.DepartmentID;
            }); 
            if (obj.data.length>0)    {
                 listCourseTypes(_CourseTypeID,"editCourseTypeID")
                 listDepartments(_DepartmentID,"editDepartmentID")
            }  
}  
        else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
  });
}                                                                                        


function edit(ID){
    var error = 0;
    
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Course Code");
            $("#editCode").addClass("highlight_error"); 
           error++;
    }  else {
            $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
     if ($('#editCourseTypeID').val()=="0"){
            $('#ErreditCourseTypeID').html("Please select Course Type");
            $("#editCourseTypeID").addClass("highlight_error"); 
           error++;
    }  else {
            $("#editCourseTypeID").removeClass("highlight_error"); 
            $('#ErreditCourseTypeID').html(""); 
    } 
    if ($('#editCourseName').val()==""){
            $('#ErreditCourseName').html("Please enter Course Name");
            $("#editCourseName").addClass("highlight_error"); 
            error++;
    }  else {
            $("#editCourseName").removeClass("highlight_error"); 
            $('#ErreditCourseName').html(""); 
    } 
    if ($('#editDepartmentID').val()==""){
            $('#ErreditDepartmentID').html("Please enter Department");
            $("#editDepartment").addClass("highlight_error"); 
            error++;
    }  else {
            $("#editDepartmentID").removeClass("highlight_error"); 
            $('#ErreditDepartmentID').html(""); 
    }  
     if(error==0){
            var param = $('#frm_edit').serialize();
            $.post(URL+"webservice.php?action=u&method=macoul",param,function(data){
            var obj = JSON.parse(data); 
            if (obj.status=="success") {
                 $('#confirmationtoedit').modal("hide");
                 $('#Success').modal("show");  
            }   else {
                $('#ErreditCommon').html(print_inlineError(obj.message));
            }
        });
     } 
}


function viewform(ID){
     $('#confirmationtoview').modal("show");
      $.post(URL+ "webservice.php?action=g&method=macoul&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            $.each(obj.data, function (index, data) {
                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                $('#viewCourseName').html(data.CourseName=="" ? "&nbsp" : data.CourseName);
                $('#viewDepartmentID').html(data.Department=="" ? "&nbsp" : data.Department);
                $('#viewCourseTypeID').html(data.CourseType=="" ? "&nbsp" : data.CourseType);
                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
               if(data.Status=="1"){
                $('#viewStatus').html("Active");    
               }
               if(data.Status=="0"){
                $('#viewStatus').html("Deactive");    
               }
            });   
        }  
  })  
}

function listCourseTypes(selected,selectboxID) {
    $.post(URL+ "webservice.php?action=lac&method=mactl","",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "<option value='0'> Select Course Type</option>";
            $.each(obj.data, function (index, data) {
                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.CourseType+'</option>';
            });   
                $('#'+selectboxID).html(html);
        } else {
            $('#ErrCommon').html( errorcontent(obj.message));
        }
    })
}

function listDepartments(selected,selectboxID) {
    $.post(URL+ "webservice.php?action=lac&method=madl","",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "<option value='0'> Select Department</option>";
            $.each(obj.data, function (index, data) {
                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.Department+'</option>';
            });   
                $('#'+selectboxID).html(html);
        } else {
            $('#ErrCommon').html( errorcontent(obj.message));
        }
    })
}
 
//Character Limitations

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphanumeric Space Dot only correct */ 
var arr = ["CourseName","editCourseName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            console.log(e.keyCode);
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [190,32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
} 
  
</script>
    